@@ -16,17 +16,6 @@ class JijaOrmDriver(DatabaseDriver):
     async def preflight(cls):
         from jija_orm import config as jija_orm_config
         from jija import config
-        import os
-        from jija_orm import exceptions
-
-        class JijaORMAppFix(jija_orm_config.App):
-            def check(self, base_path):
-                for app_models in self._App__models_modules:
-                    path = base_path.joinpath(self._App__path.replace('.', '/'), app_models.replace('.', '/') + '.py')
-                    if not os.path.exists(path):
-                        raise exceptions.AppConfigImportError(path)
-
-        jija_orm_config.App = JijaORMAppFix
 
         await jija_orm_config.JijaORM.async_init(
             project_dir=config.StructureConfig.PROJECT_PATH,
