@@ -3,8 +3,8 @@ from aiohttp import web
 
 @web.middleware
 class Middleware:
-    async def handler(self, request, handler):
+    async def handler(self, request: web.Request, handler):
         raise NotImplementedError()
 
-    async def __call__(self, request, handler):
+    async def __call__(self, request: web.Request, handler):
         return await self.handler(request, handler)
